@@ -281,7 +281,7 @@ cmStateSnapshot cmState::Reset()
     it->CompileOptions.clear();
     it->LinkOptions.clear();
     it->LinkDirectories.clear();
-    it->DirectoryEnd = pos;
+    it->CurrentScope = pos;
     it->NormalTargetNames.clear();
     it->ImportedTargetNames.clear();
     it->Properties.Clear();
@@ -503,7 +503,7 @@ bool cmState::AddScriptedCommand(std::string const& name, BT<Command> command,
       cmStrCat("Built-in flow control command \"", sName,
                "\" cannot be overridden."),
       command.Backtrace);
-    cmSystemTools::SetFatalErrorOccured();
+    cmSystemTools::SetFatalErrorOccurred();
     return false;
   }
 
@@ -819,7 +819,7 @@ cmStateSnapshot cmState::CreateBaseSnapshot()
   pos->CompileOptionsPosition = 0;
   pos->LinkOptionsPosition = 0;
   pos->LinkDirectoriesPosition = 0;
-  pos->BuildSystemDirectory->DirectoryEnd = pos;
+  pos->BuildSystemDirectory->CurrentScope = pos;
   pos->Policies = this->PolicyStack.Root();
   pos->PolicyRoot = this->PolicyStack.Root();
   pos->PolicyScope = this->PolicyStack.Root();
@@ -846,7 +846,7 @@ cmStateSnapshot cmState::CreateBuildsystemDirectorySnapshot(
     originSnapshot.Position->BuildSystemDirectory);
   pos->ExecutionListFile =
     this->ExecutionListFiles.Push(originSnapshot.Position->ExecutionListFile);
-  pos->BuildSystemDirectory->DirectoryEnd = pos;
+  pos->BuildSystemDirectory->CurrentScope = pos;
   pos->Policies = originSnapshot.Position->Policies;
   pos->PolicyRoot = originSnapshot.Position->Policies;
   pos->PolicyScope = originSnapshot.Position->Policies;
@@ -876,7 +876,7 @@ cmStateSnapshot cmState::CreateDeferCallSnapshot(
   pos->ExecutionListFile = this->ExecutionListFiles.Push(
     originSnapshot.Position->ExecutionListFile, fileName);
   assert(originSnapshot.Position->Vars.IsValid());
-  pos->BuildSystemDirectory->DirectoryEnd = pos;
+  pos->BuildSystemDirectory->CurrentScope = pos;
   pos->PolicyScope = originSnapshot.Position->Policies;
   return { this, pos };
 }
@@ -891,7 +891,7 @@ cmStateSnapshot cmState::CreateFunctionCallSnapshot(
   pos->Keep = false;
   pos->ExecutionListFile = this->ExecutionListFiles.Push(
     originSnapshot.Position->ExecutionListFile, fileName);
-  pos->BuildSystemDirectory->DirectoryEnd = pos;
+  pos->BuildSystemDirectory->CurrentScope = pos;
   pos->PolicyScope = originSnapshot.Position->Policies;
   assert(originSnapshot.Position->Vars.IsValid());
   cmLinkedTree<cmDefinitions>::iterator origin = originSnapshot.Position->Vars;
@@ -910,7 +910,7 @@ cmStateSnapshot cmState::CreateMacroCallSnapshot(
   pos->ExecutionListFile = this->ExecutionListFiles.Push(
     originSnapshot.Position->ExecutionListFile, fileName);
   assert(originSnapshot.Position->Vars.IsValid());
-  pos->BuildSystemDirectory->DirectoryEnd = pos;
+  pos->BuildSystemDirectory->CurrentScope = pos;
   pos->PolicyScope = originSnapshot.Position->Policies;
   return { this, pos };
 }
@@ -925,7 +925,7 @@ cmStateSnapshot cmState::CreateIncludeFileSnapshot(
   pos->ExecutionListFile = this->ExecutionListFiles.Push(
     originSnapshot.Position->ExecutionListFile, fileName);
   assert(originSnapshot.Position->Vars.IsValid());
-  pos->BuildSystemDirectory->DirectoryEnd = pos;
+  pos->BuildSystemDirectory->CurrentScope = pos;
   pos->PolicyScope = originSnapshot.Position->Policies;
   return { this, pos };
 }
@@ -938,6 +938,7 @@ cmStateSnapshot cmState::CreateVariableScopeSnapshot(
   pos->ScopeParent = originSnapshot.Position;
   pos->SnapshotType = cmStateEnums::VariableScopeType;
   pos->Keep = false;
+  pos->BuildSystemDirectory->CurrentScope = pos;
   pos->PolicyScope = originSnapshot.Position->Policies;
   assert(originSnapshot.Position->Vars.IsValid());
 
@@ -957,7 +958,7 @@ cmStateSnapshot cmState::CreateInlineListFileSnapshot(
   pos->Keep = true;
   pos->ExecutionListFile = this->ExecutionListFiles.Push(
     originSnapshot.Position->ExecutionListFile, fileName);
-  pos->BuildSystemDirectory->DirectoryEnd = pos;
+  pos->BuildSystemDirectory->CurrentScope = pos;
   pos->PolicyScope = originSnapshot.Position->Policies;
   return { this, pos };
 }
@@ -969,7 +970,7 @@ cmStateSnapshot cmState::CreatePolicyScopeSnapshot(
     this->SnapshotData.Push(originSnapshot.Position, *originSnapshot.Position);
   pos->SnapshotType = cmStateEnums::PolicyScopeType;
   pos->Keep = false;
-  pos->BuildSystemDirectory->DirectoryEnd = pos;
+  pos->BuildSystemDirectory->CurrentScope = pos;
   pos->PolicyScope = originSnapshot.Position->Policies;
   return { this, pos };
 }
@@ -989,7 +990,7 @@ cmStateSnapshot cmState::Pop(cmStateSnapshot const& originSnapshot)
     prevPos->BuildSystemDirectory->LinkOptions.size();
   prevPos->LinkDirectoriesPosition =
     prevPos->BuildSystemDirectory->LinkDirectories.size();
-  prevPos->BuildSystemDirectory->DirectoryEnd = prevPos;
+  prevPos->BuildSystemDirectory->CurrentScope = prevPos;
 
   if (!pos->Keep && this->SnapshotData.IsLast(pos)) {
     if (pos->Vars != prevPos->Vars) {
@@ -1072,3 +1073,12 @@ bool cmState::ParseCacheEntry(const std::string& entry, std::string& var,
 
   return flag;
 }
+
+cmState::Command cmState::GetDependencyProviderCommand(
+  cmDependencyProvider::Method method) const
+{
+  return (this->DependencyProvider &&
+          this->DependencyProvider->SupportsMethod(method))
+    ? this->GetCommand(this->DependencyProvider->GetCommand())
+    : Command{};
+}
